@@ -1,4 +1,4 @@
-/* $Id: thunar-vfs-thumb.c 28986 2008-12-07 17:32:35Z nick $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -1169,7 +1169,11 @@ thunar_vfs_thumbnail_is_valid (const gchar      *thumbnail,
     goto done0;
 
   /* verify the png signature */
+#if PNG_LIBPNG_VER_SONUM < 14
   if (G_LIKELY (png_check_sig ((png_bytep) signature, sizeof (signature))))
+#else
+  if (G_LIKELY (!png_sig_cmp ((png_bytep) signature, 0, sizeof (signature))))
+#endif
     rewind (fp);
   else
     goto done0;
