@@ -1,4 +1,4 @@
-/* $Id: thunar-application.c 28986 2008-12-07 17:32:35Z nick $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2005      Jeff Franks <jcfranks@xfce.org>
@@ -1332,116 +1332,8 @@ thunar_application_unlink_files (ThunarApplication *application,
   _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
 
-    /* check if we should permanently delete the files (user holds shift) */
-    permanently = FALSE;
-
-  /* determine the paths for the files */
-  for (lp = g_list_last (file_list); lp != NULL; lp = lp->prev, ++n_path_list)
-    {
-      /* prepend the path to the path list */
-      path_list = thunar_vfs_path_list_prepend (path_list, thunar_file_get_path (lp->data));
-
-      /* check if the file is not a local file */
-      if (!thunar_file_is_local (lp->data))
-        permanently = TRUE;
-    }
-
-  /* nothing to do if we don't have any paths */
-  if (G_UNLIKELY (n_path_list == 0))
-    return;
-
-  /* ask the user to confirm if deleting permanently */
-  if (G_UNLIKELY (permanently))
-    {
-      /* parse the parent pointer */
-      screen = thunar_util_parse_parent (parent, &window);
-
-      /* generate the question to confirm the delete operation */
-      if (G_LIKELY (n_path_list == 1))
-        {
-          message = g_strdup_printf (_("Are you sure that you want to\npermanently delete \"%s\"?"),
-                                     thunar_file_get_display_name (THUNAR_FILE (file_list->data)));
-        }
-      else
-        {
-          message = g_strdup_printf (ngettext ("Are you sure that you want to permanently\ndelete the selected file?",
-                                               "Are you sure that you want to permanently\ndelete the %u selected files?",
-                                               n_path_list),
-                                     n_path_list);
-        }
-
-      /* ask the user to confirm the delete operation */
-      dialog = gtk_message_dialog_new (window,
-                                       GTK_DIALOG_MODAL
-                                       | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                       GTK_MESSAGE_QUESTION,
-                                       GTK_BUTTONS_NONE,
-                                       "%s", message);
-      if (G_UNLIKELY (window == NULL && screen != NULL))
-        gtk_window_set_screen (GTK_WINDOW (dialog), screen);
-      gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                              GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                              GTK_STOCK_DELETE, GTK_RESPONSE_YES,
-                              NULL);
-      gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
-      gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), _("If you delete a file, it is permanently lost."));
-      response = gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
-      g_free (message);
-
-      /* perform the delete operation */
-      if (G_LIKELY (response == GTK_RESPONSE_YES))
-        {
-          /* launch the "Delete" operation */
-          thunar_application_launch (application, parent, "stock_delete",
-                                      _("Deleting files..."), unlink_stub,
-                                      path_list, path_list, NULL);
-        }
-    }
-  else
-    {
-      /* launch the "Move to Trash" operation */
-      path = thunar_vfs_path_get_for_trash ();
-      thunar_application_move_into (application, parent, path_list, path, NULL);
-      thunar_vfs_path_unref (path);
-    }
-
-  /* release the path list */
-  thunar_vfs_path_list_free (path_list);
-}
-
-
-
-/**
- * thunar_application_files_delete:
- * @application : a #ThunarApplication.
- * @parent      : a #GdkScreen, a #GtkWidget or %NULL.
- * @file_list   : the list of #ThunarFile<!---->s that should be deleted.
- *
- * Deletes all files in the @file_list and takes care of all user interaction.
- **/
-void
-thunar_application_files_delete (ThunarApplication *application,
-                                 gpointer           parent,
-                                 GList             *file_list)
-{
-  GdkModifierType state;
-  ThunarVfsPath  *path;
-  GtkWidget      *dialog;
-  GtkWindow      *window;
-  GdkScreen      *screen;
-  gboolean        permanently;
-  GList          *path_list = NULL;
-  GList          *lp;
-  gchar          *message;
-  guint           n_path_list = 0;
-  gint            response;
-
-  _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
-  _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
-
-    /* check if we should permanently delete the files (user holds shift) */
-    permanently = TRUE;
+  /* check if we should permanently delete the files (user holds shift) */
+  permanently = (gtk_get_current_event_state (&state) && (state & GDK_SHIFT_MASK) != 0);
 
   /* determine the paths for the files */
   for (lp = g_list_last (file_list); lp != NULL; lp = lp->prev, ++n_path_list)
